import numpy as np
from netCDF4 import Dataset
from datetime import datetime, timedelta

def write_nc(filename, lon, lat, data, format='NETCDF4'):
    dset = Dataset(filename, mode='w', format=format)
    
    dset.createDimension('latitude', 721)
    dset.createDimension('longitude', 1440)
    
    lats = dset.createVariable('latitude', np.float32, dimensions='latitude')
    lons = dset.createVariable('longitude', np.float32, dimensions='longitude')
    datas = dset.createVariable('z', np.float32, ('latitude', 'longitude'), zlib=True, complevel=3)
     
    dset.variables['latitude'][:] = lat
    dset.variables['longitude'][:] = lon
    dset.variables['z'][:] = data / 9.80665
    
    dset.title = 'ERA5 1979-2021 Climatology'
    
    dset.close()

ds = Dataset('7921_500hgt.nc')
lon, lat = ds['longitude'][:], ds['latitude'][:]
times = ds['time'][:]
for i in range(12):
    for j in range(43):
        print(datetime(1900,1,1) + timedelta(hours=int(times[i+12*j])))
        if j == 0:
            t = ds['z'][i+12*j,:,:]
        else:
            t += ds['z'][i+12*j,:,:]
    t = t / 43
    write_nc(f"./mean_0p25/era5-1979-2021-500mb-HGT-means-{'%02d' % (i + 1)}.nc", lon, lat, t)
